@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2008 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -435,6 +435,9 @@ static gboolean on_popup_button_press_event (G_GNUC_UNUSED GtkWidget* widget,
       return FALSE;
       break;
     /* FIXME is that neccesary? Compiler warnings and so... */
+#if GTK_CHECK_VERSION (2,14,0)
+    case GDK_DAMAGE:
+#endif
     case GDK_NOTHING:
     case GDK_DELETE:
     case GDK_DESTROY:
